pub struct SearchRequest {
pub request_id: [u8; 16],
pub query_embedding: Vec<i16>,
pub query_text: Option<String>,
pub max_results: u8,
pub include_proofs: bool,
pub model_hash: [u8; 32],
pub timestamp: i64,
pub signature: [u8; 64],
pub public_key: [u8; 32],
}Expand description
Search request sent from querier to peer over Tor.
Uses ephemeral session keys (not the node’s registered identity) to prevent peers from linking queries to registered node identities.
Fields
request_id: [u8; 16]Random request identifier.
query_embedding: Vec<i16>Query embedding vector (i16 quantized, 1536 dimensions).
query_text: Option<String>Optional query text for lexical search.
max_results: u8Maximum results to return (capped at 20).
include_proofs: boolWhether to include Merkle inclusion proofs.
model_hash: [u8; 32]BLAKE3 hash of the embedding model used.
timestamp: i64Request timestamp (Unix milliseconds).
signature: [u8; 64]Ed25519 signature over BLAKE3(CBOR(preceding fields)).
public_key: [u8; 32]Ephemeral session public key (NOT the node identity key).
Implementations
Sourceimpl SearchRequest
impl SearchRequest
Sourcepub fn signing_bytes(&self) -> [u8; 32]
pub fn signing_bytes(&self) -> [u8; 32]
Compute the signing bytes: BLAKE3 of CBOR of all fields except signature.